Crate hephae_locale

hephae-locale

Hephae’s localization module, integrated as assets. LocaleCollection maps locale codes (e.g. en-US, id-ID) to their respective Locale assets, which store locale keys to their (potentially formatted) localized strings.

See examples/text.rs for an example joint usage of localization, text, and rendering support.

Modules

arg
Defines LocaleTarget and LocaleArg, both configurable by LocaleTargetPlugin and LocaleArgPlugin, respectively.
cmd
Defines extensions for Commands and EntityCommands for convenient localized entity spawning.
def
Defines all the necessary components for localization to work, namely:
loader
Defines asset loaders for Locale and LocaleLoader.
prelude
Common imports for hephae_locale.

Structs

LocaleArgPlugin
Configures a custom LocaleArg.
LocalePlugin
Entry point for Hephae’s localization plugin, configurable with additional localization argument types and target localized receivers.
LocaleTargetPlugin
Configures a custom LocaleTarget.

Enums

HephaeLocaleSystems
Labels assigned to Hephae systems that are added to PostUpdate, responsible over all localizations.

Traits

ArgConf
LocaleArgs you can pass to LocalePlugin to conveniently configure them in one go.
TargetConf
LocaleTargets you can pass to LocalePlugin to conveniently configure them in one go.