hephae-locale
Hephae’s localization module, integrated as assets. LocaleCollection maps locale codes (e.g. en-US, id-ID) to their
respective Locale assets, which store locale keys to their (potentially formatted) localized strings.
See examples/text.rs for an example joint usage of localization, text, and rendering support.
Modules
- arg
- Defines
LocaleTargetandLocaleArg, both configurable byLocaleTargetPluginandLocaleArgPlugin, respectively. - cmd
- Defines extensions for
CommandsandEntityCommandsfor convenient localized entity spawning. - def
- Defines all the necessary components for localization to work, namely:
- loader
- Defines asset loaders for
LocaleandLocaleLoader. - prelude
- Common imports for
hephae_locale.
Structs
- Locale
ArgPlugin - Configures a custom
LocaleArg. - Locale
Plugin - Entry point for Hephae’s localization plugin, configurable with additional localization argument types and target localized receivers.
- Locale
Target Plugin - Configures a custom
LocaleTarget.
Enums
- Hephae
Locale Systems - Labels assigned to Hephae systems that are added to
PostUpdate, responsible over all localizations.
Traits
- ArgConf
LocaleArgs you can pass toLocalePluginto conveniently configure them in one go.- Target
Conf LocaleTargets you can pass toLocalePluginto conveniently configure them in one go.